documentFactory.ZipDocumentStream

|  | ## Cheshire3 Object Model: Class ZipDocumentStream

Module documentFactory :: Class ZipDocumentStream

## Class ZipDocumentStream
source code

Object Tree:

    BaseDocumentStream --+
                         |
    MultipleDocumentStream --+
                             |
       DirectoryDocumentStream --+
                                 |
                                ZipDocumentStream

Instance Methods

open_stream(self, stream)
_fetchStream(self, item)
_fetchName(self, item)
find_documents(self, session, cache=0)
Inherited from `MultipleDocumentStream`: `__init__` Inherited from `MultipleDocumentStream` (private): `_processFile`, `_processFiles` Inherited from `BaseDocumentStream`: `fetch_document`

Class Variables

Inherited from `BaseDocumentStream`: `codec`, `documents`, `factory`, `filterRe`, `format`, `length`, `locations`, `schema`, `stream`, `streamLocation`

Method Details

### open_stream(self, stream) | source code
Overrides: BaseDocumentStream.open_stream

### _fetchStream(self, item) | source code
Overrides: MultipleDocumentStream._fetchStream

### _fetchName(self, item) | source code
Overrides: MultipleDocumentStream._fetchName

### find_documents(self, session, cache=0) | source code
Overrides: DirectoryDocumentStream.find_documents